PlainProgress

Struct PlainProgress 

pub struct PlainProgress<W> { /* private fields */ }
A line-oriented progress sink for logs, pipes, and deterministic tests.

Implementations

Source

impl<W> PlainProgress<W>

pub fn new(console: Console, writer: W) -> Self

Creates a line-oriented progress sink using the supplied writer.

pub fn into_inner(self) -> W

Returns the underlying writer after all progress output has completed.

This is primarily useful for deterministic tests with an in-memory buffer.