#[non_exhaustive]pub enum DetailLevel {
Compact,
Detailed,
}Expand description
Render detail mode for reports.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Compact
Compact summary with aggregated counts and bounded finding samples.
Detailed
Full detail view for every finding provided by the report data, with locations, rule IDs, and remedies.