pub struct PlainProgress<W> { /* private fields */ }Expand description
A line-oriented progress sink for logs, pipes, and deterministic tests.
Implementations
Sourceimpl<W> PlainProgress<W>
impl<W> PlainProgress<W>
Sourcepub fn new(console: Console, writer: W) -> Self
pub fn new(console: Console, writer: W) -> Self
Creates a line-oriented progress sink using the supplied writer.
Sourcepub fn into_inner(self) -> W
pub fn into_inner(self) -> W
Returns the underlying writer after all progress output has completed.
This is primarily useful for deterministic tests with an in-memory buffer.